homology.PersDiag.bin_diag — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Topological Constructions
- homology.PersDiag

- index
- modules
- next
- previous

# homology.PersDiag.bin_diag

`PersDiag.` `bin_diag`(width, underflow=None, overflow=None)

#### Previous topic

homology.PersDiag.bin_bot

#### Next topic

homology.PersDiag.bin_len

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.